@@ -36,7 +36,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BindStaffSkillGroupList", params)
+            headers = request.headers
+            body = self.call("BindStaffSkillGroupList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BindStaffSkillGroupListResponse()
@@ -54,8 +55,66 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateAutoCalloutTask(self, request):
+        """创建自动外呼任务
+
+        :param request: Request instance for CreateAutoCalloutTask.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAutoCalloutTaskRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateAutoCalloutTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAutoCalloutTask", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateAutoCalloutTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateCCCSkillGroup(self, request):
+        """创建技能组
+
+        :param request: Request instance for CreateCCCSkillGroup.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateCCCSkillGroupRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateCCCSkillGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCCCSkillGroup", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateCCCSkillGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateCallOutSession(self, request):
-        """创建外呼会话
+        """创建外呼会话，当前仅支持双呼，即先使用平台号码呼出到坐席手机上，坐席接听后，然后再外呼用户，而且由于运营商频率限制，坐席手机号必须先加白名单，避免频控导致外呼失败。
 
         :param request: Request instance for CreateCallOutSession.
         :type request: :class:`tencentcloud.ccc.v20200210.models.CreateCallOutSessionRequest`
@@ -64,7 +123,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCallOutSession", params)
+            headers = request.headers
+            body = self.call("CreateCallOutSession", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateCallOutSessionResponse()
@@ -92,7 +152,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateSDKLoginToken", params)
+            headers = request.headers
+            body = self.call("CreateSDKLoginToken", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateSDKLoginTokenResponse()
@@ -120,7 +181,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateStaff", params)
+            headers = request.headers
+            body = self.call("CreateStaff", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateStaffResponse()
@@ -148,7 +210,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateUserSig", params)
+            headers = request.headers
+            body = self.call("CreateUserSig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateUserSigResponse()
@@ -176,7 +239,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteStaff", params)
+            headers = request.headers
+            body = self.call("DeleteStaff", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteStaffResponse()
@@ -194,6 +258,35 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAutoCalloutTask(self, request):
+        """查询自动外呼任务详情
+
+        :param request: Request instance for DescribeAutoCalloutTask.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAutoCalloutTaskRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAutoCalloutTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAutoCalloutTask", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAutoCalloutTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAutoCalloutTasks(self, request):
         """批量查询自动任务外呼
 
@@ -204,7 +297,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAutoCalloutTasks", params)
+            headers = request.headers
+            body = self.call("DescribeAutoCalloutTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAutoCalloutTasksResponse()
@@ -232,7 +326,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCCCBuyInfoList", params)
+            headers = request.headers
+            body = self.call("DescribeCCCBuyInfoList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCCCBuyInfoListResponse()
@@ -260,7 +355,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCallInMetrics", params)
+            headers = request.headers
+            body = self.call("DescribeCallInMetrics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCallInMetricsResponse()
@@ -288,7 +384,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeChatMessages", params)
+            headers = request.headers
+            body = self.call("DescribeChatMessages", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeChatMessagesResponse()
@@ -316,7 +413,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeIMCdrs", params)
+            headers = request.headers
+            body = self.call("DescribeIMCdrs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeIMCdrsResponse()
@@ -344,7 +442,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePSTNActiveSessionList", params)
+            headers = request.headers
+            body = self.call("DescribePSTNActiveSessionList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePSTNActiveSessionListResponse()
@@ -362,6 +461,35 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeProtectedTelCdr(self, request):
+        """获取主被叫受保护的电话服务记录与录音
+
+        :param request: Request instance for DescribeProtectedTelCdr.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeProtectedTelCdrRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeProtectedTelCdrResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeProtectedTelCdr", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeProtectedTelCdrResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeSeatUserList(self, request):
         """废弃接口下架
 
@@ -374,7 +502,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSeatUserList", params)
+            headers = request.headers
+            body = self.call("DescribeSeatUserList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSeatUserListResponse()
@@ -402,7 +531,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSkillGroupInfoList", params)
+            headers = request.headers
+            body = self.call("DescribeSkillGroupInfoList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSkillGroupInfoListResponse()
@@ -430,7 +560,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeStaffInfoList", params)
+            headers = request.headers
+            body = self.call("DescribeStaffInfoList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeStaffInfoListResponse()
@@ -458,7 +589,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeStaffStatusMetrics", params)
+            headers = request.headers
+            body = self.call("DescribeStaffStatusMetrics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeStaffStatusMetricsResponse()
@@ -486,7 +618,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTelCallInfo", params)
+            headers = request.headers
+            body = self.call("DescribeTelCallInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTelCallInfoResponse()
@@ -514,7 +647,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTelCdr", params)
+            headers = request.headers
+            body = self.call("DescribeTelCdr", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTelCdrResponse()
@@ -542,7 +676,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTelSession", params)
+            headers = request.headers
+            body = self.call("DescribeTelSession", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTelSessionResponse()
@@ -560,6 +695,35 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def StopAutoCalloutTask(self, request):
+        """停止自动外呼任务
+
+        :param request: Request instance for StopAutoCalloutTask.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.StopAutoCalloutTaskRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.StopAutoCalloutTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopAutoCalloutTask", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StopAutoCalloutTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UnbindStaffSkillGroupList(self, request):
         """解绑坐席所属技能组
 
@@ -570,7 +734,8 @@ class CccClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UnbindStaffSkillGroupList", params)
+            headers = request.headers
+            body = self.call("UnbindStaffSkillGroupList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UnbindStaffSkillGroupListResponse()
